@@ -71,9 +71,9 @@ function create_root {
 
 function install_deps {
     # Downgrade GLIB, resolver is broken on Windows 7
-    curl -o "${BUILD_ROOT}"/mingw-w64-x86_64-glib2-2.56.2-1-any.pkg.tar.xz \
-        https://gajim.org/downloads/snap/win/build/mingw-w64-x86_64-glib2-2.56.2-1-any.pkg.tar.xz
-    build_pacman --noconfirm -U "${BUILD_ROOT}"/mingw-w64-x86_64-glib2-2.56.2-1-any.pkg.tar.xz
+    curl -o "${BUILD_ROOT}"/mingw-w64-"${ARCH}"-glib2-2.56.2-1-any.pkg.tar.xz \
+        https://gajim.org/downloads/snap/win/build/mingw-w64-"${ARCH}"-glib2-2.56.2-1-any.pkg.tar.xz
+    build_pacman --noconfirm -U "${BUILD_ROOT}"/mingw-w64-"${ARCH}"-glib2-2.56.2-1-any.pkg.tar.xz
 
     build_pacman --noconfirm -S mingw-w64-"${ARCH}"-gtk3 mingw-w64-"${ARCH}"-"${PYTHON_ID}" \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-gobject \
@@ -87,14 +87,13 @@ function install_deps {
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-setuptools \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-pillow \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-setuptools-scm \
-        mingw-w64-"${ARCH}"-"${PYTHON_ID}"-cryptography \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-pyopenssl \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-docutils \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-certifi \
         mingw-w64-"${ARCH}"-"${PYTHON_ID}"-six
 
     PIP_REQUIREMENTS="\
-git+https://dev.gajim.org/gajim/python-nbxmpp.git
+nbxmpp==0.6.8
 git+https://dev.gajim.org/lovetox/pybonjour-python3.git
 git+https://github.com/enthought/pywin32-ctypes.git
 keyring
@@ -298,19 +297,6 @@ function cleanup_install {
 
 }
 
-function download_ssl_libs {
-    # Python needs these ssl libs but msys does not provide them
-    curl -o "${BUILD_ROOT}"/ssl.zip https://gajim.org/downloads/snap/win/build/ssl.zip
-    7z x -o"${MINGW_ROOT}"/bin "${BUILD_ROOT}"/ssl.zip
-}
-
-function move_ssl_libs {
-    # Pythons ssl module searches in that path for these dlls, if they are not there
-    # C:/Windows/system32 is searcherd and potentially wrong versioned dlls are found there
-    cp "${MINGW_ROOT}"/bin/libeay32.dll "${MINGW_ROOT}"/lib/python3.7/lib-dynload/libeay32.dll
-    cp "${MINGW_ROOT}"/bin/ssleay32.dll "${MINGW_ROOT}"/lib/python3.7/lib-dynload/ssleay32.dll
-}
-
 function build_installer {
     (cd "$BUILD_ROOT" && makensis -NOCD -DVERSION="$QL_VERSION_DESC" -DARCH="${MINGW}" "${MISC}"/gajim.nsi)
     (cd "$BUILD_ROOT" && makensis -NOCD -DVERSION="$QL_VERSION_DESC" -DARCH="${MINGW}" "${MISC}"/gajim-portable.nsi)
